<?php

function theme_ejournal_page($journal, $output) {
	return '<div class="ejournal-page">'.$output.'</div>';
}

function theme_ejournal_journal_reference($journal) {
  $path = ejournal_path_set(array('action' => 'show', 'jid' => $journal->jid));
  $output .= '<div class="ejournal" id="ejournal-' . $journal->jid . '">' . l($journal->title, $path) . "<br/>\n";
  if ($journal->description) {
    $output .= "<p>$journal->description</p>\n";
  }
  $output .= "</div>\n";  
  return $output;
}

function theme_ejournal_volume_reference($journal, $issue, $jid = FALSE) {
  if($jid) {
    $path = ejournal_path_set(array('action' => 'show', 'jid' => $issue->jid, 'vid' => 'v' . urlencode($issue->volume)));
    $out = l(ejournal_volume_reference($issue), $path);
  }
  else {
    $out = ejournal_volume_reference($issue);
  }
  return "<div class=\"volume\">" . $out . "</div>\n";
}


/** 
* theme_ejournal_issue_reference: A themeable layout that formats a single issue of a journal.
*
* @param $issue
*   An edition object.
*
* @return
*   An HTML-formatted display showing the reference name of the issue
*/

function theme_ejournal_issue_reference($journal, $issue, $full = TRUE) {  
  $output = "<div class=\"issue\">";
  if ($full) {
    $output .= l((ejournal_issue_reference($issue)), ejournal_path_set(array('action' => 'show', 'jid' => $issue->jid, 'iid' => $issue->iid)));
  } else {
    $path = ejournal_path_set(array('action' => 'show', 'jid' => $issue->jid, 'iid' => $issue->iid));
    $visible = isset($issue->number) ? t('No. ') . $issue->number : $issue->custom;
    $output .= l($visible, $path);
    $output .= "<br/>[ " . format_date($issue->date_published, 'custom', 'd. m. Y') . " ]";
  }
  $output .= "</div>\n";
  return $output;
}

function theme_ejournal_article_reference($article, $journal=NULL, $issue=NULL) { 
  return l($article->title, "node/$article->nid", array ('class' => 'article'));
}



function theme_ejournal_section_form($journal) {
	return  drupal_get_form('_ejournal_section_form', $journal);
}

function _ejournal_section_form(&$form_state, $journal) {
  $form = array ();
  $form['tid'] = array (
    '#type' => 'select',
    '#title' => t('Section'), 
    '#default_value' => NULL, 
    '#options' => ejournal_sections_get($journal->jid, NULL)
    );
  $form['jid'] = array (
    '#type' => 'hidden',
    '#value' => $journal->jid
    );
  $form['op'] = array (
    '#type' => 'submit',
    '#value' => t('Submit'));
  $form['#action'] = url(ejournal_path_set(array('action' => 'term', 'jid' => $journal->jid)));
  return  $form;
} 

function theme_ejournal_about($journal) {
  if ($journal->about_page) {
    print ejournal_theme_custom('ejournal_page', $journal, node_view(node_load($journal->about_page)));
  }
  else  {
    print ejournal_theme_custom('ejournal_archive', $journal);
  }
}

/**
* This is only call to taxonomy_term_page function
**/
function theme_ejournal_taxonomy_term_page($journal, $str_tids = '', $depth = 0, $op = 'page') {
  //TODO better to use ejournal_link_alter hook?
  //TODO remove this altogether? well, hmm, but if we want to support taxonomy/term/... from user profiles, that does not seem easy
	//TODO - add breadcrumb or inside the ejournal_page
  require_once (drupal_get_path('module', 'taxonomy') . '/taxonomy.pages.inc');// because it is not load, it is inside .inc page
  return taxonomy_term_page($str_tids, $depth, $op);
}

?>
